function t = f_getDataTable(e, dAll )
    %%
    nE = length(e);
    t  = cell(1, nE);
    %%
    %%
    for iiE = 1:nE
        d = f_adjustTimeShift(e{iiE}, dAll);
        t{iiE} = struct;
        nTC = length(e{iiE}.turbineCur);
        nTR = length(e{iiE}.turbineRef);
        
        
        %% Produced Energy
        for isCurtailedTurbine = [1 0]
            if(isCurtailedTurbine == 1)
                ii0 = 0;
                turbs = e{iiE}.turbineCur;
            else
                ii0 = ii;
                turbs = e{iiE}.turbineRef;
            end
            for ii = 1:length(turbs);
                iiT  = turbs(ii);
                
                if(isCurtailedTurbine == 1)
                    tCur    = (e{iiE}.tSetpoint:e{iiE}.tResetpoint) + e{iiE}.tStart;
                else
                    tCur    = (e{iiE}.tRefRise(ii):e{iiE}.tRefFall(ii))+e{iiE}.tStart;
                end
                tNormal = (e{iiE}.tRefNormal:e{iiE}.tRefEndNormal)+e{iiE}.tStart;

                ePCur    = d.P(iiT, tCur);
                ePNormal = d.P(iiT, tNormal);
                eAPE     = d.APE(iiT, tCur);

                ECur    = trapz(ePCur)     / length(ePCur)    * e{iiE}.tEnd;
                ENormal = trapz(ePNormal)  / length(ePNormal) * e{iiE}.tEnd;
                APE     = trapz(eAPE)  / length(eAPE) * e{iiE}.tEnd;

                t{iiE}.producedEnergy(ii+ii0) = ECur;
                t{iiE}.normallyProducedEnergy(ii+ii0) = ENormal;
                t{iiE}.estimatedEnergy(ii+ii0) = APE;
            end
            
            if(isCurtailedTurbine == 1)
                t{iiE}.totalCurtailedEnergy = sum(t{iiE}.normallyProducedEnergy-t{iiE}.producedEnergy);
            end
        end
        t{iiE}.totalProducedEnergy = sum(t{iiE}.producedEnergy);
        t{iiE}.totalNormallyProducedEnergy = sum(t{iiE}.normallyProducedEnergy);
        
        t{iiE}.powerCur = t{iiE}.producedEnergy / e{iiE}.tEnd;
        t{iiE}.powerNormal = t{iiE}.normallyProducedEnergy / e{iiE}.tEnd;
        t{iiE}.powerEstimated = t{iiE}.estimatedEnergy / e{iiE}.tEnd;
        
        %% Net Curtailed Energy
        t{iiE}.netCurtailedEnergy = sum(t{iiE}.totalNormallyProducedEnergy-t{iiE}.totalProducedEnergy);
        t{iiE}.totalGainedEnergy = t{iiE}.totalCurtailedEnergy-t{iiE}.netCurtailedEnergy;
        
        %% Wind Conditions
        tCur = (e{iiE}.tSetpoint:e{iiE}.tResetpoint) + e{iiE}.tStart;
        tNormal = (e{iiE}.tRefNormal:e{iiE}.tRefEndNormal)+e{iiE}.tStart;
        
        u    = d.u(e{iiE}.turbineCur(1), tNormal);
        t{iiE}.windspeed = mean(u);
        
        t{iiE}.uCur = mean(d.u(e{iiE}.turbineOrder, tCur), 2)';
        t{iiE}.uNormal = mean(d.u(e{iiE}.turbineOrder, tNormal), 2)';
        
        
        t{iiE}.rhoCur  = d.rhoCorrection(tCur);
        t{iiE}.rhoNormal = d.rhoCorrection(tNormal);
        
        for iiT=1:length(e{iiE}.turbineOrder)
            iiTName = e{iiE}.turbineOrder(iiT);
            uCur    = d.u(iiTName, tCur);
            uNormal = d.u(iiTName, tNormal);
            APECur  = d.APE(iiTName, tCur);
            APENormal = d.APE(iiTName, tNormal);
            TIc = f_TI(uCur, APECur, t{iiE}.rhoCur, length(uCur)-3);
            TIn = f_TI(uNormal, APENormal, t{iiE}.rhoNormal, length(uNormal)-3);
            t{iiE}.tiCur(iiT) = mean(TIc);
            t{iiE}.tiNormal(iiT) = mean(TIn);
        end
        %% Curtailment Config
        t{iiE}.duration = e{iiE}.tEnd;
        t{iiE}.cConfig = ones(size(e{iiE}.turbineOrder));
        turbsCur = ismember(e{iiE}.turbineOrder, e{iiE}.turbineCur);
        t{iiE}.cConfig(turbsCur) = t{iiE}.producedEnergy(turbsCur) ./ t{iiE}.normallyProducedEnergy(turbsCur);
        
        %% Thrust
        t{iiE}.cTNormal = f_CT(t{iiE}.uNormal, ones(length(t{iiE}.uNormal), 1))';
        t{iiE}.cTCur = f_CT(t{iiE}.uNormal, t{iiE}.cConfig)';
        
        %% Wind Direction
        t{iiE}.alphaNormal = f_meanAngle(d.alpha(e{iiE}.turbineOrder, tNormal)');
        t{iiE}.alphaCur = f_meanAngle(d.alpha(e{iiE}.turbineOrder, tCur)');
    end
end

