function [dPest, P_J, P_L] = f_predictEffectNextTurbine( e, t )
    delegate;
    for iiTName = e.turbineCur
        iiTNextName = e.turbineOrder(circshift(e.turbineOrder'==iiTName,[1,0]));
        
        iiT     = find(e.turbineOrder==iiTName);
        iiTNext = find(e.turbineOrder==iiTNextName);
        
        d0 = sqrt((xT(iiTName) - xT(iiTNextName))^2 + (yT(iiTName) - yT(iiTNextName))^2);
        d = [0 d0];
        
        %% Jensen
        a_J_Normal  = f_JensenMultiple(d, SWP_R, [1 1], f_P2U(t.powerNormal(1), mean(t.rhoNormal)), t.tiNormal(iiT));
        a_J_Curtail = f_JensenMultiple(d, SWP_R, [t.cConfig(iiT) 1], f_P2U(t.powerEstimated(1), mean(t.rhoCur)), t.tiNormal(iiT));
        
        P_J_Normal  = f_U2P(a_J_Normal(2)*t.uNormal(iiT), mean(t.rhoNormal));
        P_J_Curtail = f_U2P(a_J_Curtail(2)*t.uNormal(iiT), mean(t.rhoCur));
        dP_J        = P_J_Curtail - P_J_Normal;
        P_J         = [P_J_Curtail P_J_Normal];
        
        %% Larsen
        a_L_Normal  = f_LarsenMultiple(d, SWP_H, SWP_R, [1 1], f_P2U(t.powerNormal(1), mean(t.rhoNormal)), t.tiNormal(iiT));
        a_L_Curtail = f_LarsenMultiple(d, SWP_H, SWP_R, [t.cConfig(iiT) 1], f_P2U(t.powerEstimated(1), mean(t.rhoCur)), t.tiNormal(iiT));
        
        P_L_Normal  = f_U2P(a_L_Normal(2)*t.uNormal(iiT), mean(t.rhoNormal));
        P_L_Curtail = f_U2P(a_L_Curtail(2)*t.uNormal(iiT), mean(t.rhoCur));
        dP_L        = P_L_Curtail - P_L_Normal;
        P_L         = [P_L_Curtail P_L_Normal];
        
        %% Bontekoning
        dP_B        = (t.powerNormal(iiT) - t.powerCur(iiT)) * t.tiCur(iiTNext)/t.tiCur(iiT)^1.5*.197;
        
        %% Complete
        dP = zeros(1, length(e.turbineOrder));
        dP(1) = dP_J;
        dP(2) = dP_L;
        dP(3) = dP_B;
        
        dPest = [t.powerCur(2) - t.powerNormal(2) dP(1:3)];
    end
    %% Plot
    figure(12); clf
    bar(dPest');
    set(gca,'XTickLabel',{'Measured', 'Jensen', 'Larsen', 'Bontekoning'})
    ylabel('Power Difference T2 [kW]');
    grid on;
    title([num2str(round(100-100*t.cConfig(1))) '% curtailment (' num2str(round(t.powerNormal(1))) 'kW to ' num2str(round(t.powerCur(1))) ' kW)']);
    
end

