function [ A1, dTt ] = f_tShift2( A0, u0, alpha0, t0, xT0, yT0, rT )
    % A0                matrix to shift
    % u0                wind speed to use
    % alpha0  radians   wind direction to use
    % rT                reference turbine to use
    delegate
    %%
    t1 = t0 -min(t0);
    A1 = A0 * 0;
    u1 = u0 * 0;
    
    % Graphical distances and angle from reference turbine
    dX = (xT0-xT0(rT));
    dY = (yT0-yT0(rT));
    dL = sqrt(dX.^2+dY.^2);
    
    gamma  = atan2(dX, dY);
    
    % Wind distance from reference turbine as function of time
    alpharT = filter(ones(1,1)/1, 1, alpha0(rT,:));
    alpha0T = alpha0;
    alpha0T(rT,:) = [];
    urT = filter(ones(1,1)/1, 1, u0(rT,:));
    
    dLt = cos(  (alpharT'-pi)*ones(size(dX)) ... % angle of rT over time
                - ones(size(alpharT'))*gamma ... % geo angle of iiT
          ) .* (ones(size(alpharT'))*dL);        % geo distance of iiT
    
    % Travel duration wind
    dTt = dLt ./ (ones(size(dX))'*urT)';
    
    % Shift
    tS = t1*ones(size(dX)) + dTt;
    
    A0s = A0 * 0;
    tSs = A0 * 0;
    for iiT = 1:size(A0,1)
        [iitSs, iiIs] = sort(tS(:,iiT));
        tSs(iiT,:) = iitSs;
        A0s(iiT,:) = A0(iiT, iiIs);
    end
    A1 = A0s;
%     figure(1);
%     subplot(211);
%     plot(tSs', A0s');
%     xlim([0 100]);
%     grid on;
%     subplot(212);
%     plot(t1*ones(size(dX)), A0');
%     grid on;
%     xlim([0 100]);
end

