clc;

iiEs      = [  2    3  14   4  15   5    8];
TI        = [8.9  8.3 7.6 7.9 9.1 7.9  8.3] / 100;
tPitchIn  = [726 1197 261 261 347 393 1318];
tPitchOut = [980 1469 678 587 624 689 1510];
evalStart = [770 1235 338 296 374 420 1319];
evalEnd   = [949 1420 663 560 620 686 1514];
plotStart = [];
plotEnd   = [];

PD = iiEs*0;
PJ = PD;
PL = PD;
ED = PD;
EJ = PD;
EL = PD;

for ii=4
    iiE=iiEs(ii);
    
    tspan = ((e{iiE}.tStart):(e{iiE}.tStart+e{iiE}.tEnd));
    tShift = e{iiE}.tRefShift(1);
    
    P1  = d.APE(13, tspan);
    P2  = d.APE(12, tspan + tShift);
    V0  = f_P2U(P1, d.rhoCorrection(tspan));
    c   = d.P(13, tspan) ./ d.APE(13, tspan);
    
    PJc = f_U2P(smooth(V0.*f_Jensen(520, SWP_R, f_CT(V0, c), TI(ii))', tSmooth), d.rhoCorrection(tspan));
    PJ1 = f_U2P(smooth(V0.*f_Jensen(520, SWP_R, f_CT(V0, 1), TI(ii))', tSmooth), d.rhoCorrection(tspan));
    PLc = f_U2P(smooth(V0.*f_Larsen(520, SWP_H, SWP_R, f_CT(V0, c), TI(ii), 'calibrated')', tSmooth), d.rhoCorrection(tspan));
    PL1 = f_U2P(smooth(V0.*f_Larsen(520, SWP_H, SWP_R, f_CT(V0, 1), TI(ii), 'calibrated')', tSmooth), d.rhoCorrection(tspan));

    ED(ii)  = trapz(d.P(12, tspan(evalStart(ii):evalEnd(ii))+tShift));
    EJ(ii)  = trapz(PJc(evalStart(ii):evalEnd(ii)));
    EL(ii)  = trapz(PLc(evalStart(ii):evalEnd(ii)));
    PD(ii)  = ED(ii) / length(tspan);
    PJ(ii)  = EJ(ii) / length(tspan);
    PL(ii)  = EL(ii) / length(tspan);
    
    
    f = figure(1); clf;
    hold on;
    hf = fill([tPitchIn(ii) tPitchIn(ii) tPitchOut(ii) tPitchOut(ii)],[0 3000 3000 0], tudcolor(4), 'EdgeColor', 'none'); alpha(hf, 0.5)
    if(ii == 1)
        hf = fill([tPitchIn(2) tPitchIn(2) tPitchOut(2) tPitchOut(2)],[0 3000 3000 0], tudcolor(4), 'EdgeColor', 'none'); alpha(hf, 0.5)
    end
    plot(P1, ':', 'Color', tudcolor);
    h0 = plot(d.P(13, tspan), 'Color', tudcolor);
    h00 = plot(P2, 'Color', tudcolor(2));
    h1 = plot(PJc, 'Color', tudcolor(3));
    h2 = plot(PJ1, ':', 'Color', tudcolor(3));
    h3 = plot(PLc, 'Color', tudcolor(5));
    h4 = plot(PL1, ':', 'Color', tudcolor(5));
    grid on;
    axis tight;
    ylabel('Power [kW]');
    xlabel('Time [s]');
    title(['Experiment ' num2str(ii)]);
    if(ii == 1)
        title('Experiments 1 & 2');
    end
    legend([h0 h00 h1 h3], 'Turbine 1 (Measured)', 'Turbine 2 (Measured)', 'Turbine 2 (Jensen)', 'Turbine 2 (Larsen)', 'Location', 'NorthWest');
    f.Position = [-898 522 648 183];
end

%% Overview
figure(2); clf;
subplot(211);
hold on;
%plot([0 8], [1 1], 'Color', tudcolor(2));
h = bar(([PJ;PL]'-[PD;PD]')./[PD;PD]'*100);
set(h(1), 'FaceColor', tudcolor(3));
%set(h(2), 'FaceColor', tudcolor(2));
set(h(2), 'FaceColor', tudcolor(5));
set(gca,'ygrid','on')
ylabel('Relative Power [-]');
legend([h(1) h(2)], 'Jensen', 'Larsen', 'Location', 'SouthEast');
subplot(212);
h = bar([PJ;PL]'-[PD;PD]');
set(h(1), 'FaceColor', tudcolor(3));
%set(h(2), 'FaceColor', tudcolor(2));
set(h(2), 'FaceColor', tudcolor(5));
set(gca,'ygrid','on')
ylabel('Power Difference [kW]');
xlabel('Experiment [#]');

dif = [PJ;PL]-[PD;PD]
err = ([EJ;EL]-[ED;ED])./[ED;ED]*100

%% Multiple
figure(3); clf;
PD = zeros(7, 12);
PJ = PD;
PL = PD;
PDref = PD;
PJref = PD;
PLref = PD;
for ii = 1:7
    iiE=iiEs(ii);

    tspan = ((e{iiE}.tStart):(e{iiE}.tStart+e{iiE}.tEnd));
    APE1= d.APE(13, tspan);
    P1  = d.P(13, tspan);
    P2  = d.P(12, tspan + tShift);
    P3  = d.P(11, tspan + tShift2);
    c   = P1 ./ d.APE(13, tspan);
    V0  = f_P2U(APE1, d.rhoCorrection(tspan));

    TIx = t{iiE}.tiCur;
    TIx(1) = t{iiE}.tiNormal(1);

    UJx  = repmat(V0, 13, 1) .* f_JensenMultipleTimeSeries((0:12)*520, SWP_R, [c; ones(12, length(c))], V0, TIx);
    ULx  = repmat(V0, 13, 1) .* f_LarsenMultipleTimeSeries((0:12)*520, SWP_H, SWP_R, [c; ones(12, length(c))], V0, TIx);
    UJrefx  = repmat(V0, 13, 1) .* f_JensenMultipleTimeSeries((0:12)*520, SWP_R, [c; ones(12, length(c))], V0, t{iiE}.tiNormal);
    ULrefx  = repmat(V0, 13, 1) .* f_LarsenMultipleTimeSeries((0:12)*520, SWP_H, SWP_R, [c; ones(12, length(c))], V0, t{iiE}.tiNormal);
    for iiT=1:13
        tShift = sum(e{iiE}.tRefShift(1:(iiT-1)));
        duration = length(tspan(evalStart(ii):evalEnd(ii)));

        PD(ii, iiT) = trapz(d.P(14-iiT, tspan(evalStart(ii):evalEnd(ii))+tShift)) / duration;
        PJ(ii, iiT) = trapz(f_U2P(UJx(iiT, evalStart(ii):evalEnd(ii)), d.rhoCorrection(tspan(evalStart(ii):evalEnd(ii)))')) / duration;
        PL(ii, iiT) = trapz(f_U2P(ULx(iiT, evalStart(ii):evalEnd(ii)), d.rhoCorrection(tspan(evalStart(ii):evalEnd(ii)))')) / duration;

        PDref(ii, iiT) = trapz(d.P(14-iiT, tspan((e{iiE}.tRefNormal:e{iiE}.tRefEndNormal))+tShift)) / duration;
        PJref(ii, iiT) = trapz(f_U2P(UJrefx(iiT, e{iiE}.tRefNormal:e{iiE}.tRefEndNormal), d.rhoCorrection(tspan(e{iiE}.tRefNormal:e{iiE}.tRefEndNormal))')) / duration;
        PLref(ii, iiT) = trapz(f_U2P(ULrefx(iiT, e{iiE}.tRefNormal:e{iiE}.tRefEndNormal), d.rhoCorrection(tspan(e{iiE}.tRefNormal:e{iiE}.tRefEndNormal))')) / duration;
    end
    
    C = [mean(c(evalStart(ii):evalEnd(ii))) mean(c(evalStart(ii):evalEnd(ii))); ones(12, 2)];

    if(ii==6)
        PJ(ii, 10:13) = 0;
        PL(ii, 10:13) = 0;
        PD(ii, 10:13) = 0;
    end
    
    subplot(4,2,ii);
    hold on;
    
    %h = bar(([PJref(1:end);PLref(1:end)]' - [PDref(1:end);PDref(1:end)]')./[PDref(1:end);PDref(1:end)]'*100);
    h = bar(([PJ(ii, 1:end);PL(ii, 1:end)]' .* C(1:end,:) - [PD(ii, 1:end);PD(ii, 1:end)]')./[PD(ii, 1:end);PD(ii, 1:end)]'*100);
    %h = bar((abs([PJ;PL(1:end)]' .* C - [PJref(1:end);PLref(1:end)]' - ([PD;PD]'-[PDref;PDref]'))));
    set(h(1), 'FaceColor', tudcolor(3));
    set(h(2), 'FaceColor', tudcolor(5));
    axis tight;
    grid on;
    title(['Experiment ' num2str(ii)]);
    set(gca, 'XTick', 1:13);
    %ylim([-40 100]);
    
    if(mod(ii,2) == 1)
        ylabel('Model Error [%]');
    end
end

%%
xlabel('Turbine [#]');
subplot(426);
xlabel('Turbine [#]');
subplot(428);
h1 = bar(0,'FaceColor', tudcolor(3));
legend([h1 h(1) h(2)], '', 'Jensen', 'Larsen');
delete(h1)
axis off;