%% Clear Workspace
clear all;
close all;
clc;

%%
addpath('../MATLAB Model');
delegate;

%% Import Data
% files = {'20160905b', '20160906b', '20160907b', '20160908b', '20160909b', '20160910b'};
files = {'20160830'};
d  = f_loadDataFromFiles(files);

%% Analysis Domain
tspanExp1 = 54500:55550;
tspanExp2 = 55320:56024;
tspan = 1:42383;
turbs = 31:48;
turb1 = 13; % base
turb2 = 12; % Jensen analysis

%%
colors = lines(17);
figure(3); clf;
subplot(211);
hold on;
ylim([0 2]);
title('Curtailed');
grid on; axis tight;
subplot(212);
hold on;
ylim([0 2]);
title('Default');
grid on; axis tight;
turbs = [15 16 17 18 19 20 22 23 24 25];

tspan1 = [32000:32300];
tspan2 = [32900:-1:32430];
smoothx = 100;
meana   = [];
AWest   = [];
AEast   = [];
xsmooth = 30;
dt    = [0 40 40 20 90 0 100 60 70 70];
A = [];
for ii=1:10
    iiT = turbs(ii);
    apeWest = smooth(d.APE(iiT, tspan), xsmooth);
    pWest   = smooth(d.P(iiT, tspan), xsmooth);
    pEast   = smooth(d.P(iiT+17, tspan+dt(ii)), xsmooth);
    uWest   = smooth(d.u(iiT, tspan), xsmooth);
    uEast   = smooth(d.u(iiT+17, tspan+dt(ii)), xsmooth);
    
    subplot(211);
    plot(uEast./uWest, 'x', 'Color', colors(ii, :));
    %plot(, 'Color', colors(ii, :));
    legend('West', 'East');
    
    subplot(212);
    plot(pWest, 'x', 'Color', colors(ii, :));
    plot(apeWest, 'Color', colors(ii, :));
    legend('Power', 'APE');
    
    A = [A; [mean(uEast(1000:1500)./uWest(1000:1500)) mean(uEast(1950:2250)./uWest(1950:2250)) mean(uEast(2500:3000)./uWest(2500:3000)) mean(pWest(1950:2250)./apeWest(1950:2250))]];
end
%%
clf;
hold on;
plot(A(:,1));
plot(A(:,2));
plot(A(:,3));
plot(mean([A(:,1) A(:,3)], 2))
legend('Before', 'During', 'After', 'Before/After');
%% Power - Parameter (u,theta,omega)
figure(2); clf;
subplot(511);
plot(d.theta(turbs, tspan)');
ylabel('Pitch angle [deg]');
grid on;
axis tight;
subplot(512);
hold on;
plot(d.P(turbs, tspan)');
%plot();
ylabel('Power [kW]');
grid on;
axis tight;
subplot(513);
plot(d.u(turbs, tspan)');
ylabel('Wind speed [m/s]');
grid on;
axis tight;
subplot(514);
plot(d.omega(turbs, tspan)');
ylabel('Rotational speed [rpm]');
grid on;
axis tight;
subplot(515);
plot(d.alpha(turbs, tspan)');
ylabel('Wind direction [deg]');
grid on;
axis tight;

%%

avgt  = 10;

avgxsec = f_xsecavg(P(turbs, tspan), avgt);

f = figure;
subplot(331);
f_plotColor(f_xsecavg(P(turbs,tspan), avgt));
grid on;
axis tight;
ylabel('Power [kW]');   
subplot(334);
f_plotColor(f_xsecavg(u(turbs,tspan), avgt));
grid on;
axis tight;
ylabel('Wind speed [m/s]');
subplot(337);
f_plotColor(f_xsecavg(alpha(turbs,tspan), avgt));
grid on;
axis tight;
ylabel('Wind directon [^\circ N]');
xlabel('Time [s]');

% wake
splt = subplot(3,3, [2 3 5 6]);
colormap(f, hot(size(avgxsec, 1)));
f_plotColor(f_xsecavg(u(turbs, tspan), avgt));
grid on;
axis tight;
title(sprintf('Relative Wind speed %d-sec avg per Turbine', avgt));
xlabel('Time [#]');
ylabel('Relative Wind speed [-]');
ylim([0 max(max(u(:, tspan)))]);

V0 = u(turb1, tspan);
dS = sqrt((yT(12)-yT(13))^2+(xT(12)-xT(13))^2);
j  = f_Jensen(dS, SWP_R, f_CT(V0, 1), f_TI(u(turb1, tspan), 60)');
l  = f_Larsen(dS, SWP_H, SWP_R, f_CT(V0, 1), f_TI(u(turb1, tspan), 60)');
colors = lines(2);
plot(f_xsecavg(j'.*u(turb1, tspan), avgt), 'Color', colors(1,:), 'DisplayName', 'Jensen');
plot(f_xsecavg(l'.*u(turb1, tspan), avgt), 'Color', colors(2,:), 'DisplayName', 'Larsen');
legend(gca, 'show');

% wind conditions
splt = subplot(3,3, [8 9]);
hold on;
f_plotColor(f_xsecavg(f_TI(u(turbs, tspan), 60), avgt)*100);
grid on;
axis tight;
xlabel('Time [s]');
ylabel('Turbulence Intensity [%]')
ylim([0 40]);

%% Determine xsec

u1 = u(13, tspan);
u2 = u(12, tspan);
figure;
hold on;
grid on;
ylim([0 1]);
stds = [];
means = [];
for xsec = 1:301
    d = f_xsecavg(u2, xsec) ./ f_xsecavg(u1, xsec);
    stds(xsec) = std(d);
end
figure;
plot(stds)

%% Determine Time Shift

figure;
hold on;
grid on;
ylim([0 1]);
stds = [];
means = [];

for xsec = 1:200
    for tshift = 1:301
        u1 = u(13, tspan);
        u2 = u(12, tspan+tshift);

        d = f_xsecavg(u2, xsec) ./ f_xsecavg(u1, xsec);
        stds(xsec, tshift) = std(d);
    end
end
figure;
surf(stds);
view(0,90);
shading interp
axis tight;
xlabel('tshift');
ylabel('xsec');

tshift = 100;


%% Deficit versus...
figure;

d2d = [];
for xsec = 1:200
    d2d(xsec) = std(f_xsecavg(u2, xsec) ./ f_xsecavg(u1, xsec));
end
plot(d2d);
xsec
%% Plot Wake 0902 1:00
%plot(f_tShift(P([1 5 8 13], 1:10000), 3556:7111, -100)')
% treq = 500:1000;
% tsearch = 1:1500;
% plot(f_tShift(P([4 13],tsearch), treq, 900)')

%% Time shift 2
turbs = [13 12];
[Pshifted, dT] = f_tShift2(P(turbs,:), u(turbs,:), alpha(turbs,:), t, xT(turbs), yT(turbs), 1);
figure(1);
subplot(311);
plot(Pshifted(:, :)')
xlim([5000 15000]);
subplot(312);
cla
plot(P(turbs(1), :)')
hold on;
plot((1:size(P,2))-100, P(turbs(2), :))
xlim([5000 15000]);
subplot(313);
plot(P(turbs, :)')
xlim([5000 15000]);
%%

%%
close all;
figure(1);
plot(P(1:13, 6000:7000)');
legend('T1', 'T2', 'T3', 'T4');
grid on;
title('Raw data')
ylabel('Power [kW]');
xlabel('Time [s]');

[Pshifted, dts] = f_tShift(P(1:13, 4000:7500), 2150:2600, -100);
figure(2);
plot(Pshifted(1:4, :)');
legend('T1', 'T2', 'T3', 'T4');
grid on;
title('Time shift corrected');
ylabel('Power [kW]');
xlabel('Time [s]');

figure(3);
hold on;
plot(Pshifted(1, :) ./ Pshifted(4, :));
plot(Pshifted(2, :) ./ Pshifted(4, :));
plot(Pshifted(3, :) ./ Pshifted(4, :));
legend('T1', 'T2', 'T3');
grid on;
title('Relative to T4');
ylabel('Relative Power [-]');
xlabel('Time [s]');

figure(4);
hold on;
plot(Pshifted(1:12, 1) / Pshifted(12, 1));
plot(Pshifted(1:12, 100) / Pshifted(12, 100));
plot(Pshifted(1:12, 200) / Pshifted(12, 200));
plot(Pshifted(1:12, 300) / Pshifted(12, 300));
plot(Pshifted(1:12, 400) / Pshifted(12, 400));
legend('t=1', 't=100', 't=200', 't=300', 't=400');
grid on;
title('Relative to T4');
ylabel('Relative Power [-]');
xlabel('Turbine [#]')

%%
surf(f_tShift(P(1:13,4050:7550), -110));
shading interp
view(0,90);
axis tight;
%%
figure;
hold on;
plot(P(3, h)');
plot(APE(3, h)');
legend('P', 'APE');
%%
figure;
hold on;
plot(u(3,h));
%%
if(true)
    figure;
    for iiT = 2050:3050
        bar(P(1:13,iiT))
        ylim([0 500]);
        drawnow
    end
end

%%
figure;
subplot(211);
boxplot(P(:)-f_U2P(round(u(:)*2)/2), round(u(:)*2)/2);
grid on;
title('Absolute Error Data Points from Power Curve');
xlabel('Wind Speed [m/s]');
ylabel('Power [kW]');
xlim([0 10]);
axis tight;

subplot(212);
hist(round(u(:)*2)/2, 0:.5:10);
xlim([0 10]);
xlabel('Wind Speed [m/s]');
ylabel('Amount of Measurements [-]');
title('Amount of Measurements');
axis tight;
grid on;

%% Polar Wind Direction Volume
alphaBins = 1:5:360;

psAlpha   = histc(mean(alpha), alphaBins)/length(t); % probability segmented wind direction
sU        = histc(mean(u).^3, alphaBins); % segmented wind speed

volumes   = psAlpha.*sU;

figure;
hold on;
polar((alphaBins)/180*pi, volumes)
polar([1 1]*(90-31.6)/180*pi, [0 1]*max(volumes));
polar([1 1]*(270-31.6)/180*pi, [0 1]*max(volumes));
polar([1 1]*90/180*pi, [0 1]*max(volumes));
polar(-[1 1]*90/180*pi, [0 1]*max(volumes));
axis equal;
grid on;