%% Error TI
u=3:.01:15;

TI = .06:.02:.18;

colors = tudcolor(1:7);

figure(1);
hold on;
for ii = 1:length(TI)
    err1 = -.5./u;
    err2 = .5^2./(2*u.^2*TI(ii)^2);
    err3 = -.5^3./(2*u.^3*TI(ii)^2);
    err = sum([err1' err2' err3'], 2)*TI(ii);
    plot(u, err*100, 'Color', colors(ii,:), 'DisplayName', ['TI ' num2str(TI(ii)*100) '%']);
end
legend(gca, 'show');

grid on;
axis tight;
xlabel('Wind Speed [m/s]');
ylabel('Error Turbulence Intensity [%-points]');

%% Error TI Powercurve Method
figure(1); clf;
hold on;
P  = 0:3000;
errPCinterp = interp1(errPCU, errPC, f_P2U(P));
dUPlus  = f_P2U(P*1.002).*(1+errPCinterp) - f_P2U(P);
dUMinus = f_P2U(P) - f_P2U(P*0.998).*(1-errPCinterp);
errU_P    = max(dUPlus, dUMinus);
errU_PU   = f_P2U(P);

plot(errU_PU, errU_P, 'Color', tudcolor);
xlabel('Wind Speed [m/s]');
ylabel('Maximum Error [m/s]');
axis tight;
grid on;

%% Err TI without Taylor%% Error TI
u=3:.01:15;

TI = .06:.04:.18;

colors = tudcolor(1:7);

figure(1); clf;
hold on;
du  = 0.5;
duP = interp1(errU_PU, errU_P, u);
for ii = 1:length(TI)
    err = TI(ii) - sqrt(u.^2*TI(ii)^2+4*.5^2)./(u-du);
    plot(u, abs(err*100), 'Color', colors(ii,:), 'DisplayName', ['(u) TI ' num2str(TI(ii)*100) '%']);
end
for ii = 1:length(TI)
    err = TI(ii) - sqrt(u.^2*TI(ii)^2+(du+duP).^2)./(u+duP);
    plot(u, abs(err*100), '--', 'Color', colors(ii,:), 'DisplayName', ['(P) TI ' num2str(TI(ii)*100) '%']);
end
legend(gca, 'show');

grid on;
axis tight;
xlabel('Wind Speed [m/s]');
ylabel('Error Turbulence Intensity [%-points]');
xlim([5 14]);

%% Error P2U vs u Box Plotsf
figure(2); clf;
P   = d.P(:,abs(d.alpha(13,:) - 209) < 1);
P   = P(:)';
P2U = f_P2U(P(P>100));
U   = d.u(:,abs(d.alpha(13,:) - 209) < 1);
U   = U(:)';
U   = U(P>100);

xavg = 1:3:300;
Rsqs = xavg*0;
offs = xavg*0;
for ii=1:length(xavg)
    fit = fitlm(f_xsecavg(U,xavg(ii)), f_xsecavg(P2U,xavg(ii)));
    a   = polyfit(f_xsecavg(U,xavg(ii)), f_xsecavg(P2U,xavg(ii)), 1);
    Rsqs(ii) = fit.Rsquared.Ordinary;
    offs(ii) = a(2);
end
%%
figure(4);clf;
subplot(221);
plot(xavg, Rsqs, 'Color', tudcolor);
grid on;
xlabel('Number of Data Points in Average [-]');
ylabel('R^2 [-]');
title('(a)');
subplot(222);
plot(xavg, offs, 'Color', tudcolor);
grid on;
xlabel('Number of Data Points in Average [-]');
ylabel('Linear Intercept [m/s]');
title('(b)');
subplot(223);
group = [repmat({'1'}, length(U), 1); repmat({'60'}, length(f_xsecavg(P2U,60)), 1); repmat({'300'}, length(f_xsecavg(P2U,300)), 1); repmat({'600'}, length(f_xsecavg(P2U,600)), 1)];
boxplot([(P2U-U)'; f_xsecavg(P2U,60) - f_xsecavg(U,60); f_xsecavg(P2U,300) - f_xsecavg(U,300); f_xsecavg(P2U,600) - f_xsecavg(U,600)], group, 'Colors', tudcolor(1));
ylim([-4 4]);
grid on;
xlabel('Number of Data Points in Average [-]');
ylabel('Difference in Wind Speed [m/s]');
title('(c)');
subplot(2,2,4);
hold on;
plot(f_xsecavg(U,60), f_xsecavg(P2U,60), '.', 'Color', tudcolor);
plot(f_xsecavg(U,300), f_xsecavg(P2U,300), '.', 'Color', tudcolor(2));
plot([0 12], [0 12], 'Color', tudcolor(4), 'LineWidth', 4);
legend('N=60', 'N=300', 'u_{ss}==u_{pc}', 'Location', 'SouthEast');
xlim([3 12]);
ylim([3 12]);
grid on;
xlabel('Wind Speed Sonic Sensor [m/s]');
ylabel('Wind Speed Power Curve [m/s]');
title('(d)');

%% Qualitative Power Curve
P = [0 0 3000 3000 0];
V = [0 3 12   25   25.5];
v = 3:.1:25.5;
plot(v, interp1(V, P, v, 'pchip'), 'Color', tudcolor(1));
grid on;
xlim([0 30]);
ylim([0 3500]);
xlabel('Wind Speed [m/s]');
ylabel('Power Production [kW]');

%% Error Power Signal
figure(5); clf;
p = 800:3000;
dp = p*.01;
plot(p, p.^(1/3) - (p+dp).^(1/3));

%% Error Wind Direction
alphaSorted = d.alpha*0;
turbs = 13:-1:1;
for ii = 1:length(turbs)
    alphaSorted(turbs(ii),1:end-0*(ii-1)) = d.alpha(turbs(ii),1+0*(ii-1):end);
end
tspan = abs(d.alpha(13,:) - 209) < 1;

figure(6); clf;
hold on;
turbs = [13 12 11 9 3];
for ii = 1:length(turbs);
    iiT = turbs(ii);
    mask = d.P(13,:) > 100;
    differenceAbs = alphaSorted(iiT,mask)-alphaSorted(13,mask);
    difference = f_xsecavg(mod(differenceAbs+180, 360) - 180, 600);
    %difference = mod(difference+180, 360) - 180;
    difference(difference > 180) = difference(difference > 180) - 360;
    plot((1:length(difference))*10-5000, smooth(difference, 10), 'Color', tudcolor(ii), 'DisplayName', ['Turbine ' num2str(iiT)]);
    std(difference(500:end))
end
legend(gca, 'show');
for ii = 1:length(turbs);
    iiT = turbs(ii);
    difference = f_xsecavg(alphaSorted(iiT,:)', 600)-f_xsecavg(alphaSorted(13,:)', 600);
    difference = mod(difference+180, 360) - 180;
    difference(difference > 180) = difference(difference > 180) - 360;
    plot([0 sum(mask)], [1 1]*mean(difference(700:end)), '--', 'Color', tudcolor(ii));
end
xlim([0 17500]);
ylim([-20 10]);
xlabel('Time [min]');
ylabel('Angle Difference from Turbine 13[^o]');
grid on;
%% Wind Direction T13
u13 = f_P2U(d.P(13,1:(end-0)));
u12 = f_P2U(d.P(12,1:end));
[means, angles, N] = grpstats((u13(u13>3)-u12(u13>3)), round(d.alpha(13,(u13>3))), {'mean', 'gname', 'numel'});
angles = str2double(angles);
%%
figure(7); clf;
hold on;
plot(angles, means, 'Color', tudcolor);
plot(angles, smooth(angles, means, 5), 'Color', tudcolor(2));
grid on;
xlim([185 235]);
legend('Raw', 'Smoothed');
xlabel('Wind Direction [^o]');
ylabel('Wind Speed Difference [m/s]');
%% Turbulence Intensity per Wind Direction and Wind Speed
TIs6013rho=f_TI(d.u(13,:),d.APE(13,:),d.rhoCorrection, 60);
%    ^^          ^^          ^^
beep
%%
[means, angles, N] = grpstats(TIs60(d.APE(13,:)>100), round(d.alpha(13,d.APE(13,:)>100)/1)*1, {'mean', 'gname', 'numel'});
angles = str2double(angles);

angles2000 = angles;
angles2000(N<3000)=nan;
means2000 = means;
means2000(N<3000) = nan;
figure(9); clf;
hold on;
plot(angles, means*100, ':', 'Color', tudcolor(1));
plot(angles2000, means2000*100, 'Color', tudcolor(1));
plot([0 360], [1 1]*10, '--', 'Color', tudcolor(2));
xlabel('Wind Direction [^o]');
ylabel('Turbulence Intensity [%]');
grid on;
axis tight;
legend('N<3000', 'N>3000', 'mean 210^o - 270^o');
set(gca, 'XTick', 0:30:360);
%% Effect of dT on TI
[means60, angles60, N] = grpstats(TIs60(d.APE(13,:)>100), round(d.alpha(13,d.APE(13,:)>100)/2)*2, {'mean', 'gname', 'numel'});
angles60 = str2double(angles60);
[means120, angles120, N] = grpstats(TIs120(d.APE(13,:)>100), round(d.alpha(13,d.APE(13,:)>100)/2)*2, {'mean', 'gname', 'numel'});
angles120 = str2double(angles120);
[means300, angles300, N] = grpstats(TIs300(d.APE(13,:)>100), round(d.alpha(13,d.APE(13,:)>100)/2)*2, {'mean', 'gname', 'numel'});
angles300 = str2double(angles300);
[means600, angles600, N] = grpstats(TIs600(d.APE(13,:)>100), round(d.alpha(13,d.APE(13,:)>100)/2)*2, {'mean', 'gname', 'numel'});
angles600 = str2double(angles600);

angles2000 = angles60;
angles2000(N<3000)=nan;
means200060 = means60;
means200060(N<3000) = nan;
means2000120 = means120;
means2000120(N<3000) = nan;
means2000300 = means300;
means2000300(N<3000) = nan;
means2000600 = means600;
means2000600(N<3000) = nan;
figure(10); clf;
hold on;
plot(angles120, (means2000120-means200060)*100, 'Color', tudcolor(1));
plot(angles300, (means2000300-means200060)*100, 'Color', tudcolor(2));
plot(angles600, (means2000600-means200060)*100, 'Color', tudcolor(3));
legend('120s', '300s', '600s');
plot(angles120, (means120-means60)*100,':', 'Color', tudcolor(1));
plot(angles300, (means300-means60)*100,':', 'Color', tudcolor(2));
plot(angles600, (means600-means60)*100,':', 'Color', tudcolor(3));
xlabel('Wind Direction [^o]');
ylabel('Increase Turbulence Intensity [%-points]');
grid on;
axis tight;

%%
figure(11); clf;
TI    = TIs60(d.alpha(13,:)>205 & d.alpha(13,:)<270);
alpha = d.alpha(13, d.alpha(13,:)>205 & d.alpha(13,:)<270);
V     = f_P2U(d.APE(13, d.alpha(13,:)>205 & d.alpha(13,:)<270));
boxplot(TI(V>2)*100, round(V(V>2)), 'Color', tudcolor);
grid on;
xlabel('Wind Speed');
ylabel('Turbulence Intensity [%]');
ylim([0 40]);
%% Turbulence in the Wake
u = 5:.5:12;
M = zeros(10, length(u));
TIs = [TIs6013;TIs6012;TIs6011;TIs6010;TIs609;TIs608;TIs607;TIs606;TIs605;TIs604];
for ii=1:size(M, 1)
    [means, us, N] = grpstats(TIs(ii, abs(d.alpha(13,:)-211)<2), round(f_P2U(d.APE(13,abs(d.alpha(13,:)-211)<2))*2)/2, {'mean', 'gname', 'numel'});
    us = str2double(us);
    for ii2 = 1:length(us)
        iiU = find(us(ii2)==u);
        if(length(iiU) > 0)
            M(ii, iiU) = means(ii2);
        end
    end
end

surf(u, 12:-1:4, (M(2:10,:)-M(ones(1,9),:))*100);
xlabel('Wind Speed [m/s]');
ylabel('Turbine [#]');
zlabel('Added Turbulence Intensity [%]');
colormap(gca, buildcmap);
view(-80,40);

%% Turbulence At several Turbines
figure(12); clf;
hold on;
mask = abs(d.alpha(13,:)-211)<2;
V = round(f_P2U(d.APE(13,mask), d.rhoCorrection(mask)));
a = [repmat({'13'}, length(V), 1); repmat({'12'}, length(V), 1); repmat({'6'}, length(V), 1)];
boxplot([TIs6013(mask) TIs6012(mask) TIs606(mask)], {[V V V],a}, 'Colors', tudcolor(1:3),'factorgap',[5 2]);
xlim([23 65]);
legend('Turbine 13', 'Turbine 12', 'Turbine 6');
%% Turbulence at several Turbines Mean-std
figure(13);
[n13, x13] = hist(round(TIs6013rho(mask)*100), 1:60);
[n12, x12] = hist(round(TIs6012(mask)*100), 1:60);
[n11, x11] = hist(round(TIs6011(mask)*100), 1:60);
[n10, x10] = hist(round(TIs6010(mask)*100), 1:60);
[n9, x9] = hist(round(TIs609(mask)*100), 1:60);
[n6, x6] = hist(round(TIs606(mask)*100), 1:60);
[n5, x5] = hist(round(TIs605(mask)*100), 1:60);
clf;
hold on;
h = bar([x13; x12; x6 ]', [n13/sum(n13); n12/sum(n12); n6/sum(n6)]'*100);
set(h(1), 'FaceColor',tudcolor, 'EdgeColor', 'none')
set(h(2), 'FaceColor',tudcolor(2), 'EdgeColor', 'none')
set(h(3), 'FaceColor',tudcolor(3), 'EdgeColor', 'none')
xlim([0 40]);
plot((1:.1:100)-.5, normpdf(1:.1:100, nanmean(TIs6013(mask)*100), nanstd(TIs6013(mask)*100))*100, 'Color', tudcolor(1));
plot(1:.1:100, normpdf(1:.1:100, nanmean(TIs6012(mask)*100), nanstd(TIs6012(mask)*100))*100, 'Color', tudcolor(2));
plot((1:.1:100)+.5, normpdf(1:.1:100, nanmean(TIs606(mask)*100), nanstd(TIs606(mask)*100))*100, 'Color', tudcolor(3));

legend('Turbine 13', 'Turbine 12', 'Turbine 6');
xlabel('Turbulence Intensity [%]');
ylabel('Probability [%]');
grid on;
%% Mean and Std over Turbines
figure(14); clf;
hold on;
plot(nanmean(TIs(:, mask), 2)*100, 'Color', tudcolor)
plot(nanstd(TIs(:, mask)'*100)', 'Color', tudcolor(2));
grid on;
axis tight;
set(gca, 'XTickLabel', 13:-1:4);
xlabel('Turbine [#]');
ylabel('Mean / Standard Deviation [%-points]');
legend('Mean', 'Standard Deviation');
%% Confidence Interval TI
u   = 10;
TI  = 10;
du  = 0.5;
TIcis = 0:.1:100;
duP = interp1(f_P2U(P), dU, u);
errTI = abs(TI/100 - sqrt(u.^2*(TI/100)^2+(du+duP).^2)./(u+duP))*100;
std1 = nanstd(TIs(1, mask)*100);
meanLeft = normpdf(TIcis, TI-errTI, std1);
meanRight = normpdf(TIcis, TI+errTI, std1);

figure(15); clf;
hold on;
plot([TI TI], [0 .2], 'Color', tudcolor)
plot(TIcis, meanRight, 'Color', tudcolor(2))
plot(TIcis, meanLeft, 'Color', tudcolor(3))
plot(ones(1,2)*(TI+errTI+std1*2), [0 .2], '--', 'Color', tudcolor(2));
plot(ones(1,2)*(TI+errTI-std1*2), [0 .2], ':', 'Color', tudcolor(2));
plot(ones(1,2)*(TI-errTI-std1*2), [0 .2], '--', 'Color', tudcolor(3));
plot(ones(1,2)*(TI-errTI+std1*2), [0 .2], ':', 'Color', tudcolor(3));
xlim([0 20]);
grid on;

%% Row Influence
[means, us, N, stds] = grpstats(d.APE(14,abs(d.alpha(13,:)-211)<2)-d.APE(31,abs(d.alpha(13,:)-211)<2), round(d.alpha(13,abs(d.alpha(13,:)-211)<2)/2)*2, {'mean', 'gname', 'numel', 'std'});
us=str2double(us);
%%
figure(16); clf;
hold on;
hf = fill([0:2:360 360:-2:0], [means+2*stds;flip(means-2*stds)], tudcolor, 'EdgeColor', 'none'); alpha(hf, 0.5)
plot(us, means, 'Color', tudcolor, 'LineWidth', 3);
plot([0 360], [0 0], 'Color', tudcolor(2), 'LineWidth', 2);

figure(17); clf;
polar(us/180*pi, means+3000);
hold on;
polar(0:.01:(2*pi), (0:.01:(2*pi))*0+3000);
axis tight;
grid on;
view(90,-90);
%%
omega = (1:12)*2*pi/60;
V0    = 10;
pitch = 0:.1:30;

figure(1); clf;
hold on;

for omega=omega;
    lambda=omega*SWP_R/V0;
    lambda1=1./(1./(lambda+0.089)-0.035./(pitch.^3+1));
    Cp=0.5*(116./lambda1-.4*pitch-5).*exp(-16.5./lambda1);
    plot(pitch, Cp);
end

%% Choi and Shan
TIs = [.08  .10  .13  .15  .16  .18  .21  .24  .29];
ks  = [.040 .052 .063 .075 .083 .092 .100 .108 .117];

figure(1); clf;
hold on;
plot(TIs*100, ks, '-x', 'Color', tudcolor);
plot([0 40], [0 .16], 'Color', tudcolor(2));
grid on;
xlabel('TI [%]');
ylabel('k [-]');
axis([0 40 0 .16]);
legend('Choi and Shan', 'Equation 6.2', 'Location', 'SouthEast');