 %%
clear all;
close all;
clc;
addpath('../MATLAB Model');
delegate;

%% Load Data
files = {'20160902b', '20160905b', '20160906b', '20160907b', '20160908b', '20160909b', '20160910b', '20160915b', '20160916b', '20160917b', '20160919b', '20160927b', '20160930b', '20161001b', '20161002b', '20161003b', '20161004b', '20161005b', '20161006b', '20161007b', '20161010b', '20161017b', '20161018b', '20161019b', '20161020b', '20161027b', '20161101b'};
d = f_loadDataFromFiles(files);

%% Tabulate alpha13-P
iiT      = 12;
iiTref   = 13;
iiTalpha = 13;

uSum  = zeros(48,360);
uN    = zeros(48,360);

for ii = 1:length(d.P)
    iiAlpha = round(d.alpha(iiTalpha, ii))+1;
    if(iiAlpha > 360)
        iiAlpha = iiAlpha - 360;
    end
    uSum(:, iiAlpha) = uSum(:, iiAlpha) + d.P(:, ii);
    uN(:, iiAlpha)   = uN(:, iiAlpha) + 1;
end
uMean = uSum ./ uN;

%% Plot Measurements vs Mean T13 -> T12
figure(1);
hold on;
plot(d.alpha(13,:), d.P(13,:) - d.P(12,:), '.')
plot(uMean(13,:) - uMean(12,:))
grid on;
axis tight;
legend('Measurements', 'Mean');
xlabel('Wind direction [^o]');
ylabel('Power difference [kW]');

%% Wake Plot for different wind directions
f = figure(2); clf;
hold on;
angles = [196   201    209 211 213    221   226];
styles = {'-', '-', '-', '-', '-', '-', '-'};
for ii = 1:length(angles)
    plot(mean(f_P2U(uMean(13:-1:3, (-2:2)+angles(ii)))./f_P2U(uMean(ones(1,11)*13, (-2:2)+angles(ii))), 2), styles{ii}, 'DisplayName', [num2str(angles(ii)-1) '^o'], 'Color', tudcolor(ii));
end
ii = 4;
legend(gca, 'show');
plot(min((f_P2U(uMean(13:-1:3, (-2:2)+angles(ii)))./f_P2U(uMean(ones(1,11)*13, (-2:2)+angles(ii))))'), '--', 'DisplayName', [num2str(angles(ii)-1) '^o'], 'Color', tudcolor(ii));
plot(max((f_P2U(uMean(13:-1:3, (-2:2)+angles(ii)))./f_P2U(uMean(ones(1,11)*13, (-2:2)+angles(ii))))'), '--', 'DisplayName', [num2str(angles(ii)-1) '^o'], 'Color', tudcolor(ii));
xlabel('Turbine [#]');
ylabel('Relative Wind Speed [-]');
grid on;
axis tight;

%% Tabulate p2u13-P for alpha13=208:210
angles = 208:210;
u = 0:.1:20;
turbs = 13:-1:1;
tabS = zeros(length(u), length(turbs));
tabN = tabS*0;
for ii=1:length(d.P)
    if(abs(d.alpha(13,ii) - 211) < 2)
        V13 = f_P2U(d.APE(13,ii));
        if(V13 > 3)
            iiV = round(V13*10)+1;
            for ii2=1:length(turbs)
                iiT = turbs(ii2);
                if(ii2>1)
                    V1      = f_P2U(d.APE(iiT,ii));
                    V2      = f_P2U(d.APE(turbs(ii2-1),ii));
                    if(V1 + V2 > 3)
                        iiShift = iiShift + round(520/mean([V1/3 V2]));
                    end
                else
                    iiShift = 0;
                end
                if(V1 + V2 > 3)
                    tabS(iiV, ii2) = tabS(iiV, ii2) + f_P2U(d.APE(iiT,ii+iiShift))';
                    tabN(iiV, ii2) = tabN(iiV, ii2) + 1;
                end
            end
        end
    end
end
tab = tabS./tabN;
%% 3D wake vs u13 Absolute
figure(6); clf;
umin = 12;
surf(u(umin:end), turbs(1:10), tab(umin:length(u),1:10)');
set(gca, 'XTick', 4:13);
colormap(gca, buildcmap);
axis tight;
xlabel('Wind Speed Turbine 13 [m/s]');
ylabel('Turbine [#]');
zlabel('Wind Speed [m/s]');
%view(-16, 30);
colorbar
%% 3D wake vs u13 Relative
figure(5); clf;
umin = 46;
hold on;
surf(u(umin:end), turbs(2:10), 100-100*(tab(umin:length(u),2:10)')./tab(umin:length(u),ones(1,9))');
%surf([u(umin) u(umin) 12 12], [4 12 4 12], ones(4,4)*21.82, 'FaceColor', tudcolor(6), 'FaceAlpha',0.4, 'EdgeColor', tudcolor(6));
colormap(gca, buildcmap);
axis tight;
xlabel('Wind Speed Turbine 13 [m/s]');
ylabel('Turbine [#]');
zlabel('Relative Wake Loss [%]');
colorbar
view(-30,30);
grid on;
%% Relative Wake Loss Per Turbine
umax=length(u);
wl = 100-100*(tab(umin:umax,2:10)')./tab(umin:umax,ones(1,9))';
figure(8); clf;
subplot(121);
hold on;
style = {'-', ':', '-', '-', '-', '-'};
ts = [61 71 81 91 101 111]-umin;
for ii=1:length(ts)
    plot(mean(wl(:,(ts(ii)-5):(ts(ii)+5)), 2), style{ii}, 'DisplayName', [num2str(u(ts(ii)+umin)) 'm/s']);
end
meanwl = nanmean(nanmean(wl(:, abs(u(umin:umax)-7)>1&u(umin:umax)>5 & u(umin:umax)<12))); % exclude 6.5-7.5
meanwlT2 = nanmean(wl(1, abs(u(umin:umax)-7)>1&u(umin:umax)>5 & u(umin:umax)<12));
plot([1 9], [1 1]*meanwl, 'DisplayName', ['mean ' num2str(round(meanwl*10)/10) '%']);
legend(gca, 'show');
xlabel('Turbine [#]');
ylabel('Relative Wake Loss [%]');
set(gca, 'XTickLabel', 12:-1:4);
grid on;
title('(a)');
%% Boxplots over turbines
subplot(122);
hold on;
colors = lines(7);
mask6 = u>5.5 & u<6.5;
mask9 = u>9.5 & u<10.5;
wl6 = 100-100*tab(mask6,2:10)./tab(mask6,ones(1,9));
wl9 = 100-100*tab(mask9,2:10)./tab(mask9,ones(1,9));
a   = [2:10 2:10];
b   = [ones(1,9) zeros(1,9)];
boxplot([wl6 wl9],{a,b},'colors',[colors(1,:);colors(4,:)],'factorgap',[5 2]);
plot([1 1], [1 1], 'Color', colors(1,:));
plot([1 1], [1 1], 'Color', colors(4,:));
plot([0 30], [1 1]*meanwl, 'DisplayName', ['mean ' num2str(round(meanwl*10)/10) '%'], 'Color', colors(7,:));
title('(b)');
legend('6 m/s', '10 m/s', 'mean');
grid on;
set(gca, 'XTick', (1:10)*3.19-1.5, 'XTickLabel', 12:-1:3);
xlabel('Turbine [#]');
ylabel('Relative Wake Loss [%]');
ylim([10 35]);
%% Wake plots different wind speeds
figure(4); clf;
hold on;
plot(mean(tab(46:56, 1:10))./mean(tab(46:56, 1)));
plot(mean(tab(56:66, 1:10))./mean(tab(56:66, 1)));
plot(mean(tab(66:76, 1:10))./mean(tab(66:76, 1)));
plot(mean(tab(86:96, 1:10))./mean(tab(86:96, 1)));
plot(mean(tab(106:116, 1:10))./mean(tab(106:116, 1)));
legend('5 m/s', '6 m/s', '7 m/s', '9 m/s', '11 m/s');
xlabel('Turbine [#]');
ylabel('Wake deficit [-]');
grid on;
axis tight;
%% Boxplots
uTabMeans   = 4:13;
tabMeans = zeros(10, length(turbs));
for ii=1:size(tabMeans, 1)
    tabMeans(ii,:) = nanmean(tab(((ii+2)*10+6):((ii+3)*10+6), :));
end
%% Boxplots over wind speed
figure(5); clf;
hold on;
boxplot(100-100*tabMeans(:,2:end)'./tabMeans(:,ones(1,12))', 'Labels', uTabMeans);
plot([1 9], [1 1]*meanwl);
set(gca, 'XTickLabel', {12:-1:4, ''});
grid on;
xlabel('Wind speed [m/s]');
ylabel('Wake deficit [-]');
%% Boxplots over turbines per turbulence intensity