%% Several Wind Speeds
modelMode = 'calibrated';
h = figure(1); clf;
V0s = 8.5:.5:11;
stdTI = nanstd(TIs(:, mask)');
turbs = 13:-1:12;
absJ  = zeros(length(turbs), length(V0s));
absJmax  = errJ;
absJmin  = errJ;
absL  = errJ;
absLmax  = errJ;
absLmin  = errJ;
absD  = errJ;
absDmax  = errJ;
absDmin  = errJ;
titleTag = {'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'};
for iiV0 = 1:length(V0s)
    V0  = V0s(iiV0);

    TIval = zeros(1,length(turbs));
    Vs    = f_P2U(d.APE(13,:), d.rhoCorrection);
    
    % Data
    VD  = TIval*0;
    VDstd = VD*0;
    mask   = abs(d.alpha(13,:)-211)<2 & abs(Vs-V0) < .25;
    %gaussianWeightForWindDirectionAndWindSpeed
    shiftedMask = mask;
    for ii=1:length(turbs)
        if(ii > 1)
            iiShift = round(520./(1/6*f_P2U(d.APE(turbs(ii-1), shiftedMask), d.rhoCorrection(mask)) + 1/2*f_P2U(d.APE(ii, mask), d.rhoCorrection(shiftedMask))));
            if(ii == 2)
                shiftedMask = find(mask==1);
            end
            for iiiiShift = 1:length(iiShift)
                shiftedMask(iiiiShift) = shiftedMask(iiiiShift) + iiShift(iiiiShift);
            end
        end
        ape    = d.APE(turbs(ii), shiftedMask);
        VD(ii) = mean(f_P2U(ape, d.rhoCorrection(shiftedMask)));
        xavg = smooth(f_P2U(ape, d.rhoCorrection(shiftedMask)), 60);
        xavg0 = smooth(f_P2U(d.APE(turbs(1), mask), d.rhoCorrection(mask)), 60);
        VDstd(ii) = std(xavg);
        
        TIval(ii) = nanmean(TIs(ii, shiftedMask));
        stdTI     = nanstd(TIs(ii, shiftedMask));
    end
    aD = VD / VD(1);
    
    N = sum(mask);
    
    % Error TI
    du  = 0.5;
    duP = interp1(f_P2U(P, 1), errU_P, VD);
    errTI = abs(TIval - sqrt(VD.^2.*(TIval).^2+(du+duP).^2)./(VD+duP));
    
    aJ = f_JensenMultiple((0:9)*520, SWP_R, ones(1,10), V0, TIval, modelMode);
    aJmax = f_JensenMultiple((0:9)*520, SWP_R, ones(1,10), V0, TIval + errTI + 0*stdTI, modelMode);
    aJmin = f_JensenMultiple((0:9)*520, SWP_R, ones(1,10), V0, TIval - errTI - 0*stdTI, modelMode);
    aL = f_LarsenMultiple((0:9)*520, SWP_H, SWP_R, ones(1,10), V0, TIval, modelMode);
    aLmax = f_LarsenMultiple((0:9)*520, SWP_H, SWP_R, ones(1,10), V0, TIval + errTI + 0*stdTI, modelMode);
    aLmin = f_LarsenMultiple((0:9)*520, SWP_H, SWP_R, ones(1,10), V0, TIval - errTI - 0*stdTI, modelMode);
    
    errD = interp1(uErrU, errU_P, VD);
    
    absD(:, iiV0)  = VD;
    absDmax(:, iiV0)  = VD+errD;
    absDmin(:, iiV0)  = VD-errD;
    absJ(:, iiV0)  = aJ*VD(1);
    absJmax(:, iiV0)  = aJmax*VD(1);
    absJmin(:, iiV0)  = aJmin*VD(1);
    absL(:, iiV0)  = aL*VD(1);
    absLmax(:, iiV0)  = aLmax*VD(1);
    absLmin(:, iiV0)  = aLmin*VD(1);

    subplot(3, 2, iiV0);
    hold on;
    sF = 1/VD(1);
    sF = 1;
    %errorbar(1:10, aJ, abs(aJmin-aJ), abs(aJmax-aJ), 'x-', 'Color', tudcolor);
    hf = fill([1:10 10:-1:1], [VD-errD flip(VD+errD)]*sF, tudcolor(4), 'EdgeColor', 'none'); alpha(hf, 0.5)
    hf = fill([1:10 10:-1:1], [aLmin flip(aLmax)]*VD(1)*sF, tudcolor(2), 'EdgeColor', 'none'); alpha(hf, 0.5)
    hf = fill([1:10 10:-1:1], [aJmin flip(aJmax)]*VD(1)*sF, tudcolor, 'EdgeColor', 'none'); alpha(hf, 0.5)
    errorbar(VD*sF, errD*sF, 'x-', 'Color', tudcolor(4));
    plot(aJ*VD(1)*sF, 'Color', tudcolor, 'LineWidth', 3);
    %plot(aJmax, '--', 'Color', tudcolor);
    %plot(aJmin, '--', 'Color', tudcolor);
    %errorbar(1:10, aL*VD(1)*sF, abs(aLmin-aL)*VD(1)*sF, abs(aLmax-aL)*VD(1)*sF, 'x-', 'Color', tudcolor(2));
    plot(aL*VD(1)*sF, 'Color', tudcolor(2), 'LineWidth', 3);
    %plot(aLmax, '--', 'Color', tudcolor(2));
    %plot(aLmin, '--', 'Color', tudcolor(2));
    errorbar(VD*sF, errD*sF, 'x-', 'Color', tudcolor(4));
    plot(VD*sF, 'Color', tudcolor(4), 'LineWidth', 3);
    grid on;
    xlabel('Turbine [#]')
    ylabel('Wind Speed [m/s]');
    set(gca, 'XTick', 1:10, 'XTickLabel', turbs);
    title(['(' titleTag{iiV0} ') V_0 = ' num2str(V0) ' m/s (TI ' num2str(round(TIval(1)*1000)/10) '%, N ' num2str(N) ')']);
    axis tight;
    %ylim([V0(1)-4 V0(1)]);
end

subplot(3, 2, 2);
legend('Jensen', 'Larsen', 'Data', 'Location', 'NorthEast');
h.Position = [-2300 20 812 783];

%% Error Several Wind Speeds
h = figure(2); clf;
rmsJ = V0s*0;
rmsL = V0s*0;
for iiV0 = 1:length(V0s)
    V0  = V0s(iiV0);
    
    
    subplot(3, 2, iiV0);
    hold on;
    %fill([1:10 10:-1:1], [(absJmin(:, iiV0) - absDmax(:, iiV0))' flip((absJmax(:, iiV0) - absDmin(:, iiV0)))']./[absD(:, iiV0)' absD(:, iiV0)']*100, tudcolor(1), 'EdgeColor', 'none'); alpha(0.5)
    hf = fill([1:10 10:-1:1], [max(0, absDmax(:,iiV0) - absJmax(:,iiV0))' flip(max(0, absDmin(:,iiV0) - absJmax(:,iiV0))+min(0, absDmin(:,iiV0) - absJmin(:,iiV0)))'], tudcolor(1), 'EdgeColor', 'none'); alpha(hf, 0.5)
    hf = fill([1:10 10:-1:1], [max(0, absDmax(:,iiV0) - absLmax(:,iiV0))' flip(max(0, absDmin(:,iiV0) - absLmax(:,iiV0))+min(0, absDmin(:,iiV0) - absLmin(:,iiV0)))'], tudcolor(2), 'EdgeColor', 'none'); alpha(hf, 0.5)
    plot([1 10], [0 0], ':k', 'LineWidth', 2);
    plot((absD(:, iiV0)-absJ(:, iiV0)), 'Color', tudcolor(1), 'LineWidth', 3);
    plot((absD(:, iiV0)-absL(:, iiV0)), 'Color', tudcolor(2), 'LineWidth', 3);
    
    rmsJ(iiV0) = sqrt(sum((absJ(:, iiV0)-absD(:, iiV0)).^2));
    rmsL(iiV0) = sqrt(sum((absL(:, iiV0)-absD(:, iiV0)).^2));
    
    grid on;
    axis tight;
    title(['(' titleTag{iiV0} ') V_0 = ' num2str(V0) ' m/s']);
    set(gca, 'XTick', 1:10, 'XTickLabel', turbs);
    ylabel('Error Model [m/s]');
    xlabel('Turbine [#]');
    ylim([-1 1]);
end
subplot(3, 2, 2);
legend('Jensen', 'Larsen', 'Location', 'NorthEast');
h.Position = [-2300 20 812 783];

%% Error All Wind Speeds
V0s = 5:.1:11.5;
absD = zeros(10, length(V0s));
absDmax = absD;
absDmin = absD;
absL    = absD;
absLmax = absD;
absLmin = absD;
absJ    = absD;
absJmax = absD;
absJmin = absD;
N = V0s*0;

for iiV0 = 1:length(V0s)
    V0  = V0s(iiV0);
    
    disp([num2str(round(iiV0 / length(V0s)*100)) ' %']);

    TIval = zeros(1,length(turbs));
    Vs    = f_P2U(d.APE(13,:), d.rhoCorrection);
    
    % Data
    VD  = TIval*0;
    VDstd = VD*0;
    mask   = abs(d.alpha(13,:)-211)<2 & abs(Vs-V0) < .25;
    %gaussianWeightForWindDirectionAndWindSpeed
    shiftedMask = mask;
    for ii=1:length(turbs)
        if(ii > 1)
            iiShift = round(520./(1/6*f_P2U(d.APE(turbs(ii-1), shiftedMask), d.rhoCorrection(mask)) + 1/2*f_P2U(d.APE(ii, mask), d.rhoCorrection(shiftedMask))));
            if(ii == 2)
                shiftedMask = find(mask==1);
            end
            for iiiiShift = 1:length(iiShift)
                shiftedMask(iiiiShift) = shiftedMask(iiiiShift) + iiShift(iiiiShift);
            end
        end
        ape    = d.APE(turbs(ii), shiftedMask);
        VD(ii) = mean(f_P2U(ape, d.rhoCorrection(shiftedMask)));
        xavg = smooth(f_P2U(ape, d.rhoCorrection(shiftedMask)), 60);
        xavg0 = smooth(f_P2U(d.APE(turbs(1), mask), d.rhoCorrection(mask)), 60);
        VDstd(ii) = std(xavg);
        
        TIval(ii) = nanmean(TIs(ii, shiftedMask));
        stdTI     = nanstd(TIs(ii, shiftedMask));
    end
    aD = VD / VD(1);
    
    N(iiV0) = sum(mask);
    
    % Error TI
    du  = 0.5;
    duP = interp1(f_P2U(P, 1), errU_P, VD);
    errTI = abs(TIval - sqrt(VD.^2.*(TIval).^2+(du+duP).^2)./(VD+duP));
    
    aJ = f_JensenMultiple((0:9)*520, SWP_R, ones(1,10), V0, TIval, modelMode);
    aJmax = f_JensenMultiple((0:9)*520, SWP_R, ones(1,10), V0, TIval + errTI + 0*stdTI, modelMode);
    aJmin = f_JensenMultiple((0:9)*520, SWP_R, ones(1,10), V0, TIval - errTI - 0*stdTI, modelMode);
    aL = f_LarsenMultiple((0:9)*520, SWP_H, SWP_R, ones(1,10), V0, TIval, modelMode);
    aLmax = f_LarsenMultiple((0:9)*520, SWP_H, SWP_R, ones(1,10), V0, TIval + errTI + 0*stdTI, modelMode);
    aLmin = f_LarsenMultiple((0:9)*520, SWP_H, SWP_R, ones(1,10), V0, TIval - errTI - 0*stdTI, modelMode);
    
    absD(:, iiV0)  = VD;
    absDmax(:, iiV0)  = VD+errD;
    absDmin(:, iiV0)  = VD-errD;
    absJ(:, iiV0)  = aJ*VD(1);
    absJmax(:, iiV0)  = aJmax*VD(1);
    absJmin(:, iiV0)  = aJmin*VD(1);
    absL(:, iiV0)  = aL*VD(1);
    absLmax(:, iiV0)  = aLmax*VD(1);
    absLmin(:, iiV0)  = aLmin*VD(1);
    
end
%%
rmsJ = sqrt(mean((absJ-absD).^2));
rmsL = sqrt(mean((absL-absD).^2));
figure(3); clf;
hold on;
plot(V0s, rmsJ, 'Color', tudcolor);
plot(V0s, rmsL, 'Color', tudcolor(2));
grid on;
axis tight;
xlabel('Wind speed [m/s]');
ylabel('Root Mean Square Error [m/s]');
legend('Jensen', 'Larsen');