function [ output_args ] = f_GUI( )

    clc;
    f = figure;
    axis tight;
    subplot(211);
    hold on;
    grid on;
    set(f, 'Position', [0 0 1440 800]);

    uicontrols = cell(1, 10);
    for ii=1:10
        uicontrols{ii} = uicontrol(f, 'Style', 'slider', 'Position', [(ii-1)*124, 50, 200, 300], 'min', 0, 'max', 1, 'SliderStep', [.1 .1], 'Callback', @updateGUI);
        uicontrols{ii}.Value = 1;
    end
    uicontrols{4}.Value = 0.2;
    updateGUI();
    
    function updateGUI(s, data)
        %% Settings
        TI = .15;
        x  = 520*(0:9);
        V0 = 10.75;
        H  = 95;
        R0 = 54;
        
        cla; 
        
        c0  = ones(1, 10);
        c4  = ones(1, 10);
        for iii=1:10
            c4(iii) = uicontrols{iii}.Value;
        end
        %% Jensen
        a0  = f_JensenMultiple(x, R0, c0, V0, TI*c0);
        P0  = f_U2P(V0*a0) .* c0;
        a4  = f_JensenMultiple(x, R0, c4, V0, TI*c0);
        P4  = f_U2P(V0*a4) .* c4;
        plot(P0 / P0(1), ':', 'Color', [0    0.4470    0.7410]);
        plot(P4 / P0(1), 'Color', [0    0.4470    0.7410]);
        
        %% Larsen
        a0  = f_LarsenMultiple(x, H, R0, c0, V0, TI*c0);
        P0  = f_U2P(V0*a0) .* c0;
        a4  = f_LarsenMultiple(x, H, R0, c4, V0, TI*c0);
        P4  = f_U2P(V0*a4) .* c4;
        plot(P0 / P0(1), ':', 'Color', [0.8500    0.3250    0.0980]);
        plot(P4 / P0(1), 'Color', [0.8500    0.3250    0.0980]);
        
        %% Measurement
        plot([1.0000    0.6104    0.6235    0.6076    0.6074    0.5671    0.5857    0.5885    0.5719    0.6173]', '--', 'Color', [0.9290    0.6940    0.1250]);
        
        %% Markup
        legend('Jensen Default', 'Jensen Curtailed', 'Larsen Default', 'Larsen Curtailed', 'Measurement Data');
        xlabel('Turbine [#]');
        ylabel('Relative Turbine Power [-]');
        ylim([0 1]);
        
        disp(['Power: ' num2str(round(sum(P4))) ...
            ' | Raw curtailed: ' num2str(sprintf('%05d', round(sum(P0) - sum(P0.*c4)))) ...
            ' | Curtailed: ' num2str(sprintf('%05d', round(sum(P0) - sum(P4))))])
    end
end

