classdef GUI < handle
    %GUI The default GUI with two sliders and two graph areas.
    %
    % This GUI is a basic GUI with two sliders and two graphs. The first
    % slider is for the wind speed and the second slider for the wind
    % angle. The angle has to be inputted in degrees, with 0 degrees
    % referring to East. The left graph is intended for the flow field,
    % while the right graph can be any graph, for example the power
    % production.
    %
    % Example:
    %   gui = GUI(model);
    %   gui.setWindSpeedSlider([0 25 10]);
    %   gui.setAngleSlider([-90 90 0]);
    %   gui.build();
    
    properties
        M
        
        f
        h
        
        uiWindSpeedSlider;
        uiWindSpeedValue;
        windSpeedSlider;
        
        uiAngleSlider;
        uiAngleValue;
        angleSlider;
    end
    
    methods
        function O = GUI(M)
            
            O.M = M;
            O.f = figure;
            axes('Parent',O.f,'position',[0 0.2 1 1]);
            set(O.f, 'Position', [0 0 1440 800]);
        end
        function O = setPlot(O, h)
            O.h = h;
        end
        
        function O = setWindSpeedSlider(O, s)
            O.windSpeedSlider = s;
        end
        
        function O = setAngleSlider(O, s)
            O.angleSlider = s;
        end
        
        function build(O)
            %% Wind Speed Slider
            O.uiWindSpeedSlider = uicontrol(...
                'Parent',O.f, ...
                'Style','slider',...
                'Position',[0,0,419,23],...
                'value',O.windSpeedSlider(3),...
                'min',O.windSpeedSlider(1), ...
                'max',O.windSpeedSlider(2), ...
                'SliderStep', [1 1]/O.windSpeedSlider(2), ...
                'Callback', @O.windSpeedSliderCallback);
            addlistener(O.uiWindSpeedSlider,'Value','PreSet',@O.windSpeedSliderDrag);
            
            O.uiWindSpeedValue = uicontrol('Parent',O.f,'Style','text','Position',[440,0,140,23],...
                            'String',['V_0=' num2str(O.windSpeedSlider(3))],'BackgroundColor',O.f.Color);
                        
            %% Angle Slider
            O.uiAngleSlider = uicontrol(...
                'Parent',O.f, ...
                'Style','slider',...
                'Position',[0,0,419,43],...
                'value',O.angleSlider(3),...
                'min',O.angleSlider(1), ...
                'max',O.angleSlider(2), ...
                'SliderStep', [1 1]/O.angleSlider(2), ...
                'Callback', @O.angleSliderCallback);
            addlistener(O.uiAngleSlider,'Value','PreSet',@O.angleSliderDrag);
            
            O.uiAngleValue = uicontrol('Parent',O.f,'Style','text','Position',[440,20,140,23],...
                            'String',['alpha=' num2str(O.angleSlider(3))],'BackgroundColor',O.f.Color);
                        
            %% Evaluate with Default Parameter Values
            O.evaluateModel();
        end
        
        function O = evaluateModel(O)
            O.M.evaluate(O.windSpeedSlider(3), O.angleSlider(3));
        end
        
        function O = windSpeedSliderCallback(O, handle, event)
            v = handle.Value;
            
            O.windSpeedSlider(3) = v;
            set(O.uiWindSpeedValue, 'String', ['V_0=' num2str(O.windSpeedSlider(3))])
            
            O.evaluateModel();
        end
        
        function O = angleSliderCallback(O, handle, event)
            set(O.uiAngleValue, 'String', ['alpha=' num2str(O.uiAngleSlider.Value)])
        end
        
        function O = windSpeedSliderDrag(O, handle, event)
            set(O.uiWindSpeedValue, 'String', ['V_0=' num2str(O.uiWindSpeedSlider.Value)])
        end
        
        function O = angleSliderDrag(O, handle, event)
            set(O.uiAngleValue, 'String', ['alpha=' num2str(O.uiAngleSlider.Value)])
        end
    end
    
end

