classdef SimpleGUI < handle
    %UNTITLED Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        M;
        f;
        
        data;
        
        uiText;
    end
    
    methods
        function O = SimpleGUI(M)
            O.M = M;
            
            O.buildGUI();
        end
        
        function O = buildGUI(O)
            O.f = figure;
            set(O.f, 'Position', [0 0 1440 800]);
            
            uicontrol(O.f, ...
                'Style','pushbutton', ...
                'String','Evaluate',...
                'Position',[50 20 60 40], ...
                'Callback', @O.buttonCallback ...
            );
            uicontrol(O.f, ...
                'Style','pushbutton', ...
                'String','Animate',...
                'Position',[120 20 60 40], ...
                'Callback', @O.buttonCallback ...
            );
            O.uiText = uicontrol(O.f, ...
                'Style','edit', ...
                'Position', [50 70 200 40], ...
                'String', 'Press evaluate', ...
                'HorizontalAlignment','left', ...
                'Enable', 'inactive' ...
            );
        
        
            subplot(121);
            D = O.M.turbineType.D;
            h = surf(O.M.mesh.Z/D,O.M.mesh.Y/D, ones(size(O.M.mesh.Z)));
            shading interp;
            xlabel('z [#D]');
            ylabel('y [#D]');
            zlabel('u [m/s]');
            view(0,90);
            axis tight equal;
            colorbar;
            set(gca, 'CLim', [0, 1]);
            zlim([0 1]);
            
            subplot(122);
            plot(0,0);
            xlabel('Angle [deg]');
            ylabel('Power [MW]');
            ylim([0 O.M.turbineType.Pr*O.M.layout.N/10^6]);
            xlim([-90 90]);
        end
        
        function O = buttonCallback(O, eventdata, handles)
            if(strcmp(handles.Source.String, 'Evaluate'))
                O.evaluate();
            elseif(strcmp(handles.Source.String, 'Animate'))
                O.animate();
            end
        end
        
        function O = evaluate(O)
            set(O.uiText, 'String', 'Evaluating');
            drawnow;
            
            tic;
            
            angles = linspace(-90, 90, 50) / 180*pi;
            power = angles * 0;
            flowFieldData = ones(size(O.M.mesh.Z));
            
            ii = 0;
            for angle = angles;
                ii = ii + 1;
                O.M.evaluateWithConfig(DefaultConfig(13, angle));
                flowFieldData(:,:,ii) = O.M.wakeModel.getFlowField();
                power(ii) = sum(O.M.getPower());
                
                set(O.uiText, 'String', ['Evaluating ' num2str(ii/length(angles)*100) '%']);
                
            
                O.data{1} = angles;
                O.data{2} = flowFieldData;
                O.data{3} = power;
            
                drawnow;
            end
            
            set(O.uiText, 'String', ...
                ['Done! (' num2str(O.M.getElapsedTime()) ' seconds)']);
        end
        
        function O = animate(O)
            angles        = O.data{1};
            flowFieldData = O.data{2};
            power         = O.data{3};
            
            sizes = size(flowFieldData);
            
            for ii = 1:sizes(3)
                subplot(121);
                h = gca;
                h = h.Children;
                h.ZData = flowFieldData(:,:,ii);
                
                subplot(122);
                h = gca;
                h = h.Children;
                h.YData = [h.YData power(ii)/10^6];
                h.XData = [h.XData angles(ii)/pi*180];
                
                if(ii == 1)
                    h.YData = h.YData(2);
                    h.XData = h.XData(2);
                end
                
                pause(0.02)     % pause to control animation speed
            end
        end
    end
    
end

