%%
close all;
clear all;
clc;

%% Define Turbine Segments
segments    = {2:13, 14:30, 31:48};
angleCenter = 58.2;
angleBand   = 1;

%% Allocate Memory
power = {};
angle = {};
speed = {};
rotat = {};
mask  = {};

%%
% Iterate over turbine segments
for sii = 1:numel(segments)
    
    turbines = segments{sii};
    Nturbines = length(turbines);
    % Get data for every turbine in segment
    for ii=turbines
        tii = find(turbines==ii);
        tData = csvread(['data/data-' num2str(ii) '.csv'], 1);
        time  = tData(:,1);

        Ndata = length(time);

        if(length(power) < sii)
            power{sii}  = zeros(Nturbines, Ndata);
            angle{sii}  = zeros(Nturbines, Ndata);
            speed{sii}  = zeros(Nturbines, Ndata);
            rotat{sii}  = zeros(Nturbines, Ndata);
            mask{sii}   = zeros(Nturbines, Ndata);
        end

        power{sii}(tii, :) = tData(:,2)';
        angle{sii}(tii, :) = tData(:,4)';
        speed{sii}(tii, :) = tData(:,6)';
        rotat{sii}(tii, :) = tData(:,7)';

        angle{sii}(tii, angle{sii}(tii,:)>180)=angle{sii}(tii, angle{sii}(tii,:)>180) - 360;
    end
    meanAngles = meanAngle(angle{sii});
    mask{sii}  = repmat(abs(angleCenter - meanAngles) < angleBand, Nturbines, 1);
end
%% Post Process

relativeSpeed = speed;
relativeSpeedMasked = speed;

% Iterate over turbine segments
for sii = 1:numel(segments)
    turbines = segments{sii};
    Nturbines = length(turbines);
    
    % Relative to first turbine
    for tii = 1:Nturbines
        relativeSpeed{sii}(tii,:) = min(5, speed{sii}(tii,:) ./ speed{sii}(1,:));
    end
    % Filter ratos higher than 2
    relativeSpeed{sii}(find(relativeSpeed{sii} > 2)) = nan;
    % Mask
    relativeSpeedMasked{sii} = relativeSpeed{sii} .* mask{sii};
    relativeSpeedMasked{sii}(find(relativeSpeedMasked{sii} == 0)) = nan;
    relativeSpeedMasked{sii} = relativeSpeedMasked{sii}(:,~any(isnan(relativeSpeedMasked{sii})));
end
%% Plot
figure;
surf(relativeSpeedMasked{1});
shading interp;
view(0,90);

figure;
plot(mean(relativeSpeedMasked{1}, 2));