clear all;
close all;
clc;
%%
addpath('libraries');
addpath('classes');
addpath('classes/interfaces');
%%
Layout = WMWLayout();

% angle depends on k
k = 0.04;
[relations, order] = getWakeInteractions(Layout.z, Layout.y, atand(k)/180*pi);

colors = lines(5);

%% Basic WMW Relation Figure
if(false)
    figure;
    hold on;
    axis equal;
    for ii=1:Layout.N
        plot(Layout.z(ii), Layout.y(ii), 'o', 'Color', colors(2,:));

        for iii=1:Layout.N
            if(relations(ii,iii) == 1)
                plot([Layout.z(ii) Layout.z(iii)], [Layout.y(ii) Layout.y(iii)], 'Color', colors(3,:));
            end
        end
    end
end
%% WMW TB 31 Relation Figure
if(true)
    figure;
    hold on;
    axis equal;
    for ii=1:Layout.N
        plot(Layout.z(ii), Layout.y(ii), 'o', 'Color', colors(2,:));

        for iii=1:Layout.N
            if(relations(ii,iii) == 1)
                if(iii == 31)
                    color = colors(2,:);
                else
                    color = colors(3,:);
                end
                plot([Layout.z(ii) Layout.z(iii)], [Layout.y(ii) Layout.y(iii)], 'Color', color);
            end
        end
    end
end

%% WMW TB31 Wake Mixing
V0 = 8;
if(true)
    AindvM1  = relations*0;
    AindvM2  = relations*0;
    AindvM3  = relations*0;
    AindvM4  = relations*0;
    AtotM1 = zeros(1,Layout.N);
    AtotM2 = ones(1,Layout.N);
    AtotM3 = ones(1,Layout.N);
    AtotM4 = ones(1,Layout.N);
    
    Asq    = zeros(1,Layout.N);
    iiC = 0;
    
    figure;
    hold on;
    axis([1 48 0 1]);
    
    for ii=order % calculate wake of turbine ii
        iiC = iiC + 1;
        z0 = Layout.z(ii);
        y0 = Layout.y(ii);
        
        for iii=order(1:iiC) % look at turbines in front
            if(relations(iii,ii)) % if turbine iii has effect on ii
                z1 = Layout.z(iii);
                y1 = Layout.y(iii);
                d = sqrt((z1-z0)^2+(y1-y0)^2);

                aM1 = getInductionFactor(V0*AtotM1(iii));
                aM2 = getInductionFactor(V0*AtotM2(iii));
                aM3 = getInductionFactor(V0*AtotM3(iii));
                aM4 = getInductionFactor(V0*AtotM4(iii));
                R = 54;
                r = R + k * d;
                K = R/r;

                AindvM1(iii,ii) = 1 - (1-(1-2*aM1)) .* K.^2;
                AindvM2(iii,ii) = 1 - (1-(1-2*aM2)) .* K.^2;
                AindvM3(iii,ii) = 1 - (1-(1-2*aM3)) .* K.^2;
                AindvM4(iii,ii) = 1 - (1-(1-2*aM4)) .* K.^2;
                
                Asq(ii) = Asq(ii) + (1-AindvM1(iii,ii))^2;
                AtotM2(ii) = AtotM2(ii) * AindvM2(iii,ii);
                AtotM3(ii) = AtotM3(ii) - AindvM3(iii,ii);
                AtotM4(ii) = min(AtotM4(ii), 1-AindvM4(iii,ii));
            end
        end
        
        AtotM1(ii) = sqrt(1-Asq(ii));
    end
    
    plot(AtotM1);
    plot(AtotM2);
    plot(AtotM3);
    plot(AtotM4);
    legend('Momentum','Multiply', 'Subtract', 'Max', 'Location', 'SouthWest')

    plot([14 14], [0 1], 'Color', colors(5,:));
    plot([31 31], [0 1], 'Color', colors(5,:));
end